CVS: python/msp430 bsl.py,1.7,1.8

Chris Liechti <[email protected]>
Newsgroups gmane.comp.hardware.texas-instruments.msp430.gcc.cvs
Message-ID <[email protected]>
Update of /cvsroot/mspgcc/python/msp430
In directory sc8-pr-cvs1.sourceforge.net:/tmp/cvs-serv6625/python/msp430

Modified Files:
	bsl.py 
Log Message:
add main erase

Index: bsl.py
===================================================================
RCS file: /cvsroot/mspgcc/python/msp430/bsl.py,v
retrieving revision 1.7
retrieving revision 1.8
diff -u -w -d -r1.7 -r1.8
--- bsl.py	14 Jun 2005 09:42:38 -0000	1.7
+++ bsl.py	12 Aug 2005 21:10:44 -0000	1.8
@@ -759,18 +759,27 @@
         for i in range(self.meraseCycles):
             if i == 1: sys.stderr.write("Additional Mass Erase Cycles...\n")
             self.bslTxRx(self.BSL_MERAS,            #Command: Mass Erase
-                                0xff00,             #Any address within flash memory.
+                                0xfffe,             #Any address within flash memory.
                                 0xa506)             #Required setting for mass erase!
         self.passwd = None                          #No password file required!
         #print "Mass Erase complete"
         #Transmit password to get access to protected BSL functions.
         self.txPasswd()
 
+    def actionMainErase(self):
+        """Erase the main flash memory only"""
+        sys.stderr.write("Main Erase...\n")
+        sys.stderr.flush()
+        self.bslTxRx(self.BSL_ERASE,                #Command: Segment Erase
+                            0xfffe,                 #Any address within flash memory.
+                            0xa504)                 #Required setting for main erase!
+        self.passwd = None                          #Password gets erased
+
     def actionSegmentErase(self, address):
         """Erase the memory segemnts. Address parameter is an address within the
         segment to be erased"""
         self.bslTxRx(self.BSL_ERASE,                #Command: Segment Erase
                             address,                #Any address within flash memory.
                             0xa502)                 #Required setting for segment erase!
 
     def makeActionSegmentErase(self, address):



-------------------------------------------------------
@@ -759,18 +759,27 @@
         segment to be erased"""
         self.bslTxRx(self.BSL_ERASE,                #Command: Segment Erase
-                            address,                #Any address within flash memory.
+                            address,                #Any address within flash segment.
                             0xa502)                 #Required setting for segment erase!
 
SF.Net email is Sponsored by the Better Software Conference & EXPO
September 19-22, 2005 * San Francisco, CA * Development Lifecycle Practices
Agile & Plan-Driven Development * Managing Projects & Teams * Testing & QA
Security * Process Improvement & Measurement * http://www.sqe.com/bsce5sf
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.